<?php $TRANSLATIONS = array(
"Music" => "מוזיקה",
"songs" => "שירים",
"albums" => "אלבומים",
"Add to playlist" => "הוספה לרשימת ההשמעה",
"Add album to playlist" => "הוסף את האלבום לרשימת ההשמעה",
"Play" => "נגן",
"Pause" => "השהה",
"Previous" => "קודם",
"Next" => "הבא",
"Mute" => "השתק",
"Unmute" => "בטל השתקה",
"Rescan Collection" => "סריקת אוסף מחדש",
"Artist" => "מבצע",
"Album" => "אלבום",
"Title" => "כותרת"
);
